WhatsappElixir.HTTP (whatsapp_elixir v0.1.9)

Module to handle HTTP requests for the WhatsApp Elixir library.

Summary

Functions

api_version(custom_config \\ [])

base_url(custom_config \\ [])

config(custom_config \\ [])

@spec config(keyword()) :: keyword()

delete(endpoint, params \\ %{}, opts \\ [], url_override \\ false)

Sends a DELETE request to the specified endpoint with the given parameters.

get(endpoint, params \\ %{}, opts \\ [], url_overide \\ false)

get_url(url, opts \\ [], headers \\ [])

post(endpoint, body, opts \\ [], include_phone_number_id \\ true, content_type \\ "application/json")

Sends a POST request to the specified endpoint with the given body.