WhatsappElixir.Static (whatsapp_elixir v0.1.9)

Utility functions for processing data received from the WhatsApp webhook.

Summary

Functions

Helper function to check if the field changed in the data received from the webhook.

Extracts the audio of the sender from the data received from the webhook.

Extracts the author of the message from the data received from the webhook.

Extracts the delivery status of the message from the data received from the webhook.

Extracts the document of the sender from the data received from the webhook.

Extracts the image of the sender from the data received from the webhook.

Extracts the response of the interactive message from the data received from the webhook.

Extracts the location of the sender from the data received from the webhook.

Extracts the text message of the sender from the data received from the webhook.

Extracts the message id of the sender from the data received from the webhook.

Extracts the timestamp of the message from the data received from the webhook.

Gets the type of the message sent by the sender from the data received from the webhook.

Extracts the mobile number of the sender from the data received from the webhook.

Extracts the name of the sender from the data received from the webhook.

Extracts the video of the sender from the data received from the webhook.

Checks if the data received from the webhook is a message.

Functions

changed_field(data)

Helper function to check if the field changed in the data received from the webhook.

get_audio(data)

Extracts the audio of the sender from the data received from the webhook.

get_author(data)

Extracts the author of the message from the data received from the webhook.

get_delivery(data)

Extracts the delivery status of the message from the data received from the webhook.

get_document(data)

Extracts the document of the sender from the data received from the webhook.

get_image(data)

Extracts the image of the sender from the data received from the webhook.

get_interactive_response(data)

Extracts the response of the interactive message from the data received from the webhook.

get_location(data)

Extracts the location of the sender from the data received from the webhook.

get_message(data)

Extracts the text message of the sender from the data received from the webhook.

get_message_id(data)

Extracts the message id of the sender from the data received from the webhook.

get_message_timestamp(data)

Extracts the timestamp of the message from the data received from the webhook.

get_message_type(data)

Gets the type of the message sent by the sender from the data received from the webhook.

get_mobile(data)

Extracts the mobile number of the sender from the data received from the webhook.

get_name(data)

Extracts the name of the sender from the data received from the webhook.

get_video(data)

Extracts the video of the sender from the data received from the webhook.

is_message(data)

Checks if the data received from the webhook is a message.