WhatsappElixir.HTTP (whatsapp_elixir v0.1.9)
View SourceModule to handle HTTP requests for the WhatsApp Elixir library.
Summary
Functions
Sends a DELETE request to the specified endpoint with the given parameters.
Sends a POST request to the specified endpoint with the given body.